@@ -78,5 +78,5 @@ if __name__ == '__main__':
     transits_mask = []
     for i in range(0, int(candidate['number']) - 1):
         transits_mask.append({"P": candidates.iloc[i]["period"], "T0": candidates.iloc[i]["t0"],
-                              "D": candidates.iloc[i]["duration"]})
+                              "D": candidates.iloc[i]["duration"] * 2})
     vetter.run(cpus, candidate=candidate, star_df=star_df.iloc[0], transits_df=transits_df, transits_mask=transits_mask)
